.. cooler documentation master file, created by
   sphinx-quickstart on Sun Jan 17 11:53:23 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Cooler
======

Cooler is a Python support library for .cool files: an efficient storage format for high resolution genomic interaction matrices.

The cooler package aims to provide the following functionality:

* Build contact matrices at any genomic resolution.
* Query contact matrices.
* Export and visualize the data.
* Perform scalable out-of-core operations on the data.
* Provide a clean and well-documented Python API to interact with the data.

Follow cooler development on `GitHub <https://github.com/mirnylab/cooler>`_.


Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   datamodel
   schema
   api
   cli
   releasenotes


* :ref:`genindex`
* :ref:`Glossary`